/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'emoji', 'de', {
	searchPlaceholder: 'Emoji suchen…',
	searchLabel: 'Input field responsible for searching and filtering emoji inside panel.', // MISSING
	navigationLabel: 'Groups navigation for emoji sections.', // MISSING
	title: 'Emoji-Liste',
	groups: {
		people: 'Personen',
		nature: 'Natur und Tiere',
		food: 'Essen und Getränke',
		travel: 'Reisen und Orte',
		activities: 'Aktivitäten',
		objects: 'Objekte',
		symbols: 'Symbole',
		flags: 'Flaggen'
	}
} );
